@@ -146,7 +146,8 @@ typedef SOCKET grn_sock;
 #    include <unistd.h>
 #  endif /* HAVE_UNISTD_H */
 
-#  ifndef __off64_t_defined
+#  ifdef BSD
+/* BSD doesn't define off64_t. So we use off_t for off64_t. */
 typedef off_t off64_t;
 #  endif
 
